{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Login" %}{% endblock %}
{% block content %}
    <h1>{% trans "Login" %}</h1>
    <form method="post">
        {% csrf_token %}
        {{ form.as_p }}
        <button type="submit">{% trans "Login" %}</button>
    </form>
    <p><a href="{% url 'accounts:password_reset' %}">{% trans "Forgot your password?" %}</a></p>
    <p><a href="{% url 'accounts:register' %}">{% trans "Don't have an account? Register here." %}</a></p>
{% endblock %}
