{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Password Reset Sent" %}{% endblock %}
{% block content %}
    <h1>{% trans "Password Reset Sent" %}</h1>
    <p>{% trans "Check your email for the reset link." %}</p>
{% endblock %}
