{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Password Reset Complete" %}{% endblock %}
{% block content %}
    <h1>{% trans "Password Reset Complete" %}</h1>
    <p>{% trans "Your password has been reset." %} <a href="{% url 'accounts:login' %}">{% trans "Login" %}</a></p>
{% endblock %}
